@@ -11,14 +11,14 @@
 
 class TethysAppBase(object):
     """
-    Base class used for building apps
+    Base class used to define the app class for Tethys apps.
     """
     name = ''
     index = ''
     icon = ''
+    package = ''
     root_url = ''
     color = ''
-    package = ''
 
     def __repr__(self):
         """
@@ -34,7 +34,10 @@ class TethysAppBase(object):
     
     def persistent_stores(self):
         """
-        May return a list of PersistentStore objects
+        Define this method to register persistent stores for your app. You may define up to 5 persistent stores for an app.
+
+        Returns:
+          list or tuple: A list or tuple of PersistentStore objects.
         """
         return None
 
