@@ -16,10 +16,17 @@ from sqlalchemy import create_engine
 
 class PersistentStore(object):
     """
-    An object that stores the data for a Tethys Persistent store
+    An object that stores the registration data for a Tethys Persistent Store.
+
+    Args:
+      name(string): The name of the persistent store.
+      initializer(string): Path to the initialization function for the persistent store. Use dot-notation with a colon delineating the function (e.g.: "foo.bar:function").
+      spatial(bool, optional): PostGIS spatial extension will be enabled on the persistent store if True. Defaults to False.
+      postgis(bool, deprecated): PostGIS spatial extension will be enabled on the persistent store if True. Defaults to False. Deprecated, use spatial.
+
     """
 
-    def __init__(self, name, initializer, postgis=False, spatial=False):
+    def __init__(self, name, initializer, spatial=False, postgis=False):
         """
         Constructor
         """
